@@ -1,7 +1,7 @@
 #
 # $Source: /home/nlfm/Zircon/lib/RCS/Channel.tcl,v $
-# $Date: 1998/07/14 15:42:14 $
-# $Revision: 1.18.1.171 $
+# $Date: 1998/07/21 09:19:17 $
+# $Revision: 1.18.1.172 $
 #
 #
 package provide zircon 1.18
@@ -172,6 +172,11 @@ proc channel_show {this args} {
 	$wndw register $this "$this doLeave {}" $del
   	$wndw setIcon $this $wname
   	makeCBody $this $w $rchan $chan $net $args $look
+	switch {} [$this logfile] {} default {
+	    switch {} [$this logfd] {
+	    	logOpen $this a 0 [$this logfile]
+	    }
+	}
 	switch {} $xc {} default { eval $xc }
 	$this defaultTags
 	$this configure -dwin [WBoard -channel $this]
