@@ -1,7 +1,7 @@
 #
 # $Source: /home/nlfm/Zircon/lib/RCS/IRC.tcl,v $
-# $Date: 1998/06/24 11:13:38 $
-# $Revision: 1.18.1.54 $
+# $Date: 1998/07/21 12:59:25 $
+# $Revision: 1.18.1.55 $
 #
 package provide zircon 1.18
 #
@@ -9,6 +9,9 @@ package provide zircon 1.18
 #
 proc ctcpAnswer {net usr nk cp} {
     handleOn $net CTCPREPLY [list $nk $cp]
+    if {[string match ZIRCON* $cp]} {
+	if {[zirconReply $net $usr $nk $cp]} return
+    }
     set chn {}
     foreach x [$usr channels] {
 	if {[$x active] && [[$x wid] visible]} {lappend chn $x}
