@@ -1,7 +1,7 @@
 #
 # $Source: /home/nlfm/Zircon/lib/RCS/Net.tcl,v $
-# $Date: 1998/07/16 11:11:14 $
-# $Revision: 1.18.1.151 $
+# $Date: 1998/07/21 12:59:28 $
+# $Revision: 1.18.1.152 $
 #
 package provide zircon 1.18
 #
@@ -97,7 +97,7 @@ proc net_configure {this args} {
 		set ndata(lagmeter) $val
 	    }
 	-toInfo -
-	-noconfirm {
+	-noConfirm {
 		set ndata($name) {}
 		foreach x $val {lappend ndata($name) [string toupper $x]}
 	    }
