@@ -1,7 +1,7 @@
 #
 # $Source: /home/nlfm/Zircon/lib/RCS/initial.tcl,v $
-# $Date: 1998/07/13 09:33:48 $
-# $Revision: 1.18.1.172 $
+# $Date: 1998/07/16 11:11:21 $
+# $Revision: 1.18.1.173 $
 #
 # ----------------------------------------------------------------------
 #   AUTHOR:  Lindsay Marshall <lindsay.marshall@newcastle.ac.uk>
@@ -136,12 +136,12 @@ proc checkRE {exp} { return [expr {![catch {regexp -- $exp a}]}] }
 proc helper {ptn cmd args} {
     global currentNet
     if {![checkRE $ptn]} {
-	tellError {} Error "Bad helper file regular expression $ptn"
+	tellError {} Error "Bad helper file regular expression \"$ptn\""
     } {
 	set usr [lindex $args 0]
 	switch {} $usr { set usr .* } default {
 	    if {![checkRE $usr]} {
-		tellError {} Error "Bad helper user regular expression $usr"
+		tellError {} Error "Bad helper user regular expression \"$usr\""
 		return
 	    }
 	}
